==> gmic_2.8.0.tar.gz: gmic-2.8.0/gmic-qt/src/FilterParameters/LinkParameter.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file LinkParameter.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_LINKPARAMETER_H
#define GMIC_QT_LINKPARAMETER_H

#include <Qt>
#include "AbstractParameter.h"
class QLabel;

class LinkParameter : public AbstractParameter {
  Q_OBJECT
public:
  LinkParameter(QObject * parent = nullptr);
  ~LinkParameter();
  bool addTo(QWidget *, int row) override;
  QString textValue() const override;
  void setValue(const QString & value) override;
  void reset() override;
  bool initFromText(const char * text, int & textLength) override;
public slots:
  void onLinkActivated(const QString & link);

private:
  QLabel * _label;
  QString _text;
  QString _url;
  Qt::AlignmentFlag _alignment;
};

#endif // GMIC_QT_LINKPARAMETER_H

==> gmic_2.9.8.tar.gz: gmic-2.9.8/gmic-qt/src/FilterParameters/LinkParameter.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file LinkParameter.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_LINKPARAMETER_H
#define GMIC_QT_LINKPARAMETER_H

#include <Qt>
#include "AbstractParameter.h"
class QLabel;

namespace GmicQt
{

class LinkParameter : public AbstractParameter {
  Q_OBJECT
public:
  LinkParameter(QObject * parent = nullptr);
  ~LinkParameter() override;
  int size() const override;
  bool addTo(QWidget *, int row) override;
  QString value() const override;
  QString defaultValue() const override;
  void setValue(const QString & value) override;
  void reset() override;
  bool initFromText(const char * text, int & textLength) override;
public slots:
  void onLinkActivated(const QString & link);

private:
  QLabel * _label;
  QString _text;
  QString _url;
  Qt::AlignmentFlag _alignment;
};

} // namespace GmicQt

#endif // GMIC_QT_LINKPARAMETER_H
